##  Multiple Subscriptions
You can control whether users can have multiple subscriptions for a single Fact Sheet. By default, a user can subscribe to a Fact Sheet multiple times under different Subscription Roles. It can be limited to one subscription per user per Fact Sheet by selecting Disabled.
